# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimm.endpoint import endpoint_data
import json

class QueryLocationDateClustersRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2020-09-30', 'QueryLocationDateClusters','imm')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_CustomLabels(self): # String
		return self.get_query_params().get('CustomLabels')

	def set_CustomLabels(self, CustomLabels):  # String
		self.add_query_param('CustomLabels', CustomLabels)
	def get_Order(self): # String
		return self.get_query_params().get('Order')

	def set_Order(self, Order):  # String
		self.add_query_param('Order', Order)
	def get_ProjectName(self): # String
		return self.get_query_params().get('ProjectName')

	def set_ProjectName(self, ProjectName):  # String
		self.add_query_param('ProjectName', ProjectName)
	def get_LocationDateClusterLevels(self): # Array
		return self.get_query_params().get('LocationDateClusterLevels')

	def set_LocationDateClusterLevels(self, LocationDateClusterLevels):  # Array
		self.add_query_param("LocationDateClusterLevels", json.dumps(LocationDateClusterLevels))
	def get_Sort(self): # String
		return self.get_query_params().get('Sort')

	def set_Sort(self, Sort):  # String
		self.add_query_param('Sort', Sort)
	def get_MaxResults(self): # Integer
		return self.get_query_params().get('MaxResults')

	def set_MaxResults(self, MaxResults):  # Integer
		self.add_query_param('MaxResults', MaxResults)
	def get_LocationDateClusterEndTimeRange(self): # Struct
		return self.get_query_params().get('LocationDateClusterEndTimeRange')

	def set_LocationDateClusterEndTimeRange(self, LocationDateClusterEndTimeRange):  # Struct
		self.add_query_param("LocationDateClusterEndTimeRange", json.dumps(LocationDateClusterEndTimeRange))
	def get_Title(self): # String
		return self.get_query_params().get('Title')

	def set_Title(self, Title):  # String
		self.add_query_param('Title', Title)
	def get_NextToken(self): # String
		return self.get_query_params().get('NextToken')

	def set_NextToken(self, NextToken):  # String
		self.add_query_param('NextToken', NextToken)
	def get_DatasetName(self): # String
		return self.get_query_params().get('DatasetName')

	def set_DatasetName(self, DatasetName):  # String
		self.add_query_param('DatasetName', DatasetName)
	def get_LocationDateClusterStartTimeRange(self): # Struct
		return self.get_query_params().get('LocationDateClusterStartTimeRange')

	def set_LocationDateClusterStartTimeRange(self, LocationDateClusterStartTimeRange):  # Struct
		self.add_query_param("LocationDateClusterStartTimeRange", json.dumps(LocationDateClusterStartTimeRange))
	def get_Address(self): # Struct
		return self.get_query_params().get('Address')

	def set_Address(self, Address):  # Struct
		self.add_query_param("Address", json.dumps(Address))
	def get_CreateTimeRange(self): # Struct
		return self.get_query_params().get('CreateTimeRange')

	def set_CreateTimeRange(self, CreateTimeRange):  # Struct
		self.add_query_param("CreateTimeRange", json.dumps(CreateTimeRange))
	def get_UpdateTimeRange(self): # Struct
		return self.get_query_params().get('UpdateTimeRange')

	def set_UpdateTimeRange(self, UpdateTimeRange):  # Struct
		self.add_query_param("UpdateTimeRange", json.dumps(UpdateTimeRange))
	def get_ObjectId(self): # String
		return self.get_query_params().get('ObjectId')

	def set_ObjectId(self, ObjectId):  # String
		self.add_query_param('ObjectId', ObjectId)
